autowisp.database.data_model.provenance.telescope_access module — AutoWISP documentation

# autowisp.database.data_model.provenance.telescope_access module

## Class Inheritance Diagram

Define the telescope access dataset table for the pipeline

class autowisp.database.data_model.provenance.telescope_access.TelescopeAccess(**kwargs)

  Bases: `DataModelBase`

  The table describing the telescope access

  id

    A unique identifier for each row.

  observer_id

    A unique identifier for the observer

  telescope_id

    A unique identifier of the telescope

  timestamp

    When record was last changed